%bcond_with bootstrap

Name:           apache-commons-lang3
Version:        3.16.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Provides a host of helper utilities for the java.lang API
License:        Apache-2.0
URL:            https://commons.apache.org/lang
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://archive.apache.org/dist/commons/lang/source/commons-lang3-%{version}-src.tar.gz
Patch1:         0001-Remove-test-dependency-on-JUnit-Pioneer.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:biz.aQute.bndlib)
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.hamcrest:hamcrest)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
%endif

%description
The standard Java libraries fail to provide enough methods for
manipulation of its core classes. The Commons Lang Component provides
these extra methods.
The Commons Lang Component provides a host of helper utilities for the
java.lang API, notably String manipulation methods, basic numerical
methods, object reflection, creation and serialization, and System
properties. Additionally it contains an inheritable enum type, an
exception structure that supports multiple types of nested-Exceptions
and a series of utilities dedicated to help with building methods, such
as hashCode, toString and equals.

With version of commons-lang 3.x, developers decided to change API and
therefore created differently named artifact and jar files. This is
the new version, while apache-commons-lang is the compatibility
package.

%{?javadoc_package}

%prep
%setup -q -n commons-lang3-%{version}-src

%patch -P 1 -p1

%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_dep org.openjdk.jmh:jmh-core
%pom_remove_dep org.openjdk.jmh:jmh-generator-annprocess
%pom_remove_dep org.apache.commons:commons-text

%mvn_file : %{name} commons-lang3

# testParseSync() test fails on ARM and PPC64LE for unknown reason
sed -i 's/\s*public void testParseSync().*/@org.junit.jupiter.api.Disabled\n&/' \
    src/test/java/org/apache/commons/lang3/time/FastDateFormatTest.java

# non-deterministic tests fail randomly
rm src/test/java/org/apache/commons/lang3/RandomStringUtilsTest.java

# Missing dependencies
rm src/test/java/org/apache/commons/lang3/HashSetvBitSetTest.java

# Remove limits and Java 11 options
sed -i '/<argLine>/d' pom.xml

%build
# See "-DcommonsLang3Version" in maven-surefire for the tested version
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt



%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.16.0-2.mga10
+ Revision: 2227326
- Mageia 10 Mass Rebuild

* Sun Sep 01 2024 neoclust <neoclust> 3.16.0-1.mga10
+ Revision: 2092452
- New version 3.16.0

* Tue May 21 2024 ns80 <ns80> 3.14.0-1.mga10
+ Revision: 2065587
- new version 3.14 for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 3.13.0-1.mga10
+ Revision: 1986590
- Update to upstream version 3.13.0

* Mon Jul 25 2022 neoclust <neoclust> 3.12.0-3.mga9
+ Revision: 1871004
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 3.12.0-2.mga9
+ Revision: 1870186
- Fix BR for bootstrap

* Tue Jun 07 2022 neoclust <neoclust> 3.12.0-1.mga9
+ Revision: 1863283
- New version 3.12.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Aug 21 2020 neoclust <neoclust> 3.11-1.mga8
+ Revision: 1617251
- New version

* Sat Feb 15 2020 umeabot <umeabot> 3.8.1-2.mga8
+ Revision: 1527509
- Mageia 8 Mass Rebuild

* Wed Jul 17 2019 daviddavid <daviddavid> 3.8.1-1.mga8
+ Revision: 1422181
- Update to upstream version 3.8.1
- Resolves: rhbz#1619243
- Fix incorrect OSGi metadata
- Resolves: rhbz#1636556

* Sat Dec 15 2018 neoclust <neoclust> 3.7-1.mga7
+ Revision: 1341394
- Revert to version 3.7

* Sun Nov 18 2018 guillomovitch <guillomovitch> 3.8.1-1.mga7
+ Revision: 1331283
- new version 3.8.1

* Thu Sep 20 2018 umeabot <umeabot> 3.4-7.mga7
+ Revision: 1277588
- Mageia 7 Mass Rebuild

* Thu Jun 15 2017 neoclust <neoclust> 3.4-6.mga6
+ Revision: 1107786
- Really disable tests

* Sun May 14 2017 neoclust <neoclust> 3.4-5.mga6
+ Revision: 1101233
- Fix parsing of ISO dates with UTC TZ

* Wed Mar 02 2016 neoclust <neoclust> 3.4-4.mga6
+ Revision: 982617
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 3.4-3.mga6
+ Revision: 975495
- First rebuild of the java stack
- sync package apache-commons-lang3 with fedora

* Sun Dec 20 2015 zezinho <zezinho> 3.4-1.mga6
+ Revision: 912433
- new version

* Thu Dec 25 2014 pterjan <pterjan> 3.3.2-2.mga5
+ Revision: 805730
- Clean rebuild
- Sync with Fedora 21 (and update to 3.3.2)
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 3.1-6.mga5
+ Revision: 749059
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1-5.mga5
+ Revision: 677814
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 3.1-4.mga4
+ Revision: 545645
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 3.1-3.mga4
+ Revision: 501516
- Disable tests
- Build with xmvn

* Fri Jan 11 2013 umeabot <umeabot> 3.1-2.mga3
+ Revision: 345766
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 13 2012 dmorgan <dmorgan> 3.1-1.mga3
+ Revision: 293297
- New version

* Wed Nov 23 2011 gil <gil> 3.0.1-1.mga2
+ Revision: 171513
- imported package apache-commons-lang3

